Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1187)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/suggestions/Tile.java

Issue 2790463003: ntp_tiles: Cleanup enum names (Closed)
Patch Set: add back histogram enums Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/suggestions/Tile.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/suggestions/Tile.java b/chrome/android/java/src/org/chromium/chrome/browser/suggestions/Tile.java
index 067927d2a08234c4d4938d98038881247506b930..1f77745c23876a4a66822cafbecf6123ad58b4e1 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/suggestions/Tile.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/suggestions/Tile.java
@@ -7,9 +7,8 @@ package org.chromium.chrome.browser.suggestions;
import android.graphics.drawable.Drawable;
import android.support.annotation.Nullable;
-import org.chromium.chrome.browser.ntp.MostVisitedTileType;
-import org.chromium.chrome.browser.ntp.MostVisitedTileType.MostVisitedTileTypeEnum;
-import org.chromium.chrome.browser.ntp.NTPTileSource.NTPTileSourceEnum;
+import org.chromium.chrome.browser.suggestions.TileSource.TileSourceEnum;
+import org.chromium.chrome.browser.suggestions.TileVisualType.TileVisualTypeEnum;
/**
* Holds the details to populate a site suggestion tile.
@@ -20,11 +19,11 @@ public class Tile implements OfflinableSuggestion {
private final String mWhitelistIconPath;
private final int mIndex;
- @NTPTileSourceEnum
+ @TileSourceEnum
private final int mSource;
- @MostVisitedTileTypeEnum
- private int mType = MostVisitedTileType.NONE;
+ @TileVisualTypeEnum
+ private int mType = TileVisualType.NONE;
@Nullable
private Drawable mIcon;
@@ -38,10 +37,10 @@ public class Tile implements OfflinableSuggestion {
* @param whitelistIconPath The path to the icon image file, if this is a whitelisted tile.
* Empty otherwise.
* @param index The index of this tile in the list of tiles.
- * @param source The {@code NTPTileSource} that generated this tile.
+ * @param source The {@code TileSource} that generated this tile.
*/
public Tile(String title, String url, String whitelistIconPath, int index,
- @NTPTileSourceEnum int source) {
+ @TileSourceEnum int source) {
mTitle = title;
mUrl = url;
mWhitelistIconPath = whitelistIconPath;
@@ -125,27 +124,26 @@ public class Tile implements OfflinableSuggestion {
/**
* @return The source of this tile. Used for metrics tracking. Valid values are listed in
- * {@code NTPTileSource}.
+ * {@code TileSource}.
*/
- @NTPTileSourceEnum
+ @TileSourceEnum
public int getSource() {
return mSource;
}
/**
* @return The visual type of this tile. Valid values are listed in
* {@link MostVisitedTileType}.
*/
- @MostVisitedTileTypeEnum
+ @TileVisualTypeEnum
public int getType() {
return mType;
}
/**
* Sets the visual type of this tile. Valid values are listed in
- * {@link MostVisitedTileType}.
+ * {@link TileVisualType}.
*/
- public void setType(@MostVisitedTileTypeEnum int type) {
+ public void setType(@TileVisualTypeEnum int type) {
mType = type;
}
@@ -125,27 +124,26 @@ public class Tile implements OfflinableSuggestion {
}
/**
- * @return The visual type of this tile. Valid values are listed in
- * {@link MostVisitedTileType}.
+ * @return The visual type of this tile. Valid values are listed in {@link TileVisualType}.
*/

Powered by Google App Engine
This is Rietveld 408576698